// -*- c++ -*- 
//
// BeMailAccount
// Copyright (c) 2001, Okada Jun
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. The name of author may not be used to endorse or promote products
// derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 


#include <View.h>
#include <StringView.h>
#include <TextControl.h>
#include <Button.h>
#include <Screen.h>
#include "BMAAccountDialog.h"


static BRect sFrame(0, 0, 300, 100);

enum
{
  OK       = 'Lokx',
  CANCEL   = 'Lcnl',
  MODIFIED = 'Lmfd',
};


BMAAccountDialog::BMAAccountDialog(BHandler *target, BMessage *msg)
  : BWindow(sFrame,
	    "account dialog",
	    B_MODAL_WINDOW,
	    B_NOT_RESIZABLE)
  , mTarget(target)
  , mMessage(msg)
{
  BView *baseView;
  BStringView *label;
  BTextControl *text;
  BButton *ok, *cancel;

  baseView = new BView(sFrame, NULL, B_FOLLOW_NONE, B_WILL_DRAW);
  baseView->SetViewColor(::ui_color(B_PANEL_BACKGROUND_COLOR));
  this->AddChild(baseView);

  label = new BStringView(BRect(0, 0, 0, 0),
			  NULL,
			  "Enter New Account Name.");
  label->SetFont(be_bold_font);
  label->MoveTo(10, 10);
  label->ResizeToPreferred();
  baseView->AddChild(label);
  
  text = new BTextControl(BRect(sFrame.left + 10,
				label->Frame().bottom + 8,
				sFrame.right - 10,
				label->Frame().bottom + 8),
			  "text",
			  "",
			  "",
			  new BMessage(OK));

  mText = text;
  text->SetModificationMessage(new BMessage(MODIFIED));
  text->SetDivider(0);
  baseView->AddChild(text);

  cancel = new BButton(BRect(0, 0, 0, 0),
		       "cancel",
		       "Cancel",
		       new BMessage(CANCEL));
  cancel->ResizeToPreferred();
  cancel->MoveTo(sFrame.RightBottom()
		 - BPoint(cancel->Frame().Width(), cancel->Frame().Height())
		 - BPoint(10, 10));
  baseView->AddChild(cancel);

  ok = new BButton(BRect(0, 0, 0, 0),
		   "ok",
		   "Ok",
		   new BMessage(OK));
  mOk = ok;
  ok->SetEnabled(false);
  ok->ResizeToPreferred();
  ok->MoveTo(cancel->Frame().LeftBottom()
		 - BPoint(ok->Frame().Width(), ok->Frame().Height())
		 - BPoint(10, 0));
  baseView->AddChild(ok);
}
  
		       
BMAAccountDialog::~BMAAccountDialog(void)
{
  delete mMessage;
}


void
BMAAccountDialog::MessageReceived(BMessage *msg)
{
  switch (msg->what)
    {
    default:
      BWindow::MessageReceived(msg);
      break;


    case CANCEL:
      {
	this->Quit();
	break;
      }

    case OK:
      {
	if (*mText->Text() == '\0')
	  break;

	mMessage->AddString("data", mText->Text());
	mTarget->Looper()->PostMessage(mMessage, mTarget);

	this->Quit();
	break;
      }

    case MODIFIED:
      {
	if (*mText->Text() == '\0')
	  mOk->SetEnabled(false);
	else
	  mOk->SetEnabled(true);
	break;
      }
    }
}


void
BMAAccountDialog::Go(void)
{
  BRect screenFrame, frame;

  frame = this->Frame();
  screenFrame = BScreen().Frame();

  this->MoveTo((screenFrame.Width() - frame.Width()) / 2,
	       (screenFrame.Height() - frame.Height()) / 3);
  this->Show();
  this->Lock();
  mText->MakeFocus();
  this->Unlock();
}

