// -*- c++ -*- 
//
// BeMailAccount
// Copyright (c) 2001, Okada Jun
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. The name of author may not be used to endorse or promote products
// derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 


#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <getopt.h>
#include <Window.h>
#include <Application.h>
#include <Deskbar.h>
#include <Message.h>
#include <Messenger.h>
#include <E-mail.h>
#include "BMAIcon.h"
#include "BMADefs.h"


class BMAApplication : public BApplication
{
public:
  BMAApplication(void);
  virtual ~BMAApplication(void);

protected:
  virtual void ArgvReceived(int32 argc, char **argv);

private:
  void SendToProperty(BMessage *msg);
  void CheckNow(void);
  void SetSchedule(const char *arg);
  void SetEvery(const char *arg);
  void SetBegin(const char *arg);
  void SetEnd(const char *arg);
};


BMAApplication::BMAApplication(void)
  : BApplication(BMA_APP_SIGNATURE)
{
#if 1
  BDeskbar deskbar;

  if (! deskbar.HasItem(BMA_APP_SIGNATURE))
    deskbar.AddItem(new BMAIcon());

  this->PostMessage(B_QUIT_REQUESTED);
#else
  BWindow *win = new BWindow(BRect(100, 100, 115, 115),
			     "",
			     B_BORDERED_WINDOW,
			     B_NOT_RESIZABLE);
  win->SetSizeLimits(15, 15, 15, 15);
  win->ResizeTo(15, 15);
  win->AddChild(new BMAIcon());
  win->Show();
#endif
}


BMAApplication::~BMAApplication(void)
{
}


static const char *
sHelp = 
"Usage: BeMailAccount [options]\n"
"Options: [default in brackets after descriptions]\n"
"Configuration:\n"
"  --help          print this message\n"
"Operation:\n"
"  --check         check new mail now\n"
"Schedule:\n"
"  --schedule=DAY  set mail check schedule to DAY\n"
"                  [never|weekday|everyday|continuously]\n"
"  --every=TIME    set mail check interval to TIME sec\n"
"  --begin=TIME    set mail check begin time to TIME sec\n"
"  --end=TIME      set mail check end time to TIME sec\n"
;


void
BMAApplication::ArgvReceived(int32 argc, char **argv)
{
  int c;
  static struct option long_options[] =
  {
    { "check",    0, 0, 'c' },
    { "help",     0, 0, 'h' },
    { "schedule", 1, 0, 'SCH' },
    { "every",    1, 0, 'EVE' },
    { "begin",    1, 0, 'BEG' },
    { "end",      1, 0, 'END' },
    { 0 },
  };

  while (1)
    {
      c = ::getopt_long(argc, argv, "hc", long_options, NULL);

      if (c == -1)
	break;

      switch (c)
	{
	default:
	  printf("unknown option.\n");
	  break;

	case 'h':
	  printf("%s", sHelp);
	  break;

	case 'c':
	  this->CheckNow();
	  break;

	case 'SCH':
	  this->SetSchedule(::optarg);
	  break;

	case 'EVE':
	  this->SetEvery(::optarg);
	  break;

	case 'BEG':
	  this->SetBegin(::optarg);
	  break;

	case 'END':
	  this->SetEnd(::optarg);
	  break;
	}
    }
}


void
BMAApplication::SendToProperty(BMessage *msg)
{
  msg->AddSpecifier("Looper", BMA_PROPERTY_NAME);
  BMessenger(DESKBAR_APP_SIGNATURE).SendMessage(msg);
}


void
BMAApplication::CheckNow(void)
{
  BMessage msg(BMA_CHECK_NOW);
  this->SendToProperty(&msg);
}


void
BMAApplication::SetSchedule(const char *arg)
{
  int32 data;

  if (::strcmp(arg, "never") == 0)
    data = B_CHECK_NEVER;
  else if (::strcmp(arg, "weekdays") == 0)
    data = B_CHECK_WEEKDAYS;
  else if (::strcmp(arg, "everyday") == 0)
    data = B_CHECK_DAILY;
  else if (::strcmp(arg, "continuously") == 0)
    data = B_CHECK_CONTINUOUSLY;
  else
    {
      printf("invalid value \"%s\" for schedule.\n", arg);
      return;
    }

  BMessage msg(BMA_SET_CHECK_DAYS);
  msg.AddInt32("data", data);
  this->SendToProperty(&msg);
}


void
BMAApplication::SetEvery(const char *arg)
{
  BMessage msg(BMA_SET_CHECK_INTERVAL);
  msg.AddInt32("data", ::atoi(arg));
  this->SendToProperty(&msg);
}


void
BMAApplication::SetBegin(const char *arg)
{
  BMessage msg(BMA_SET_CHECK_BEGIN_TIME);
  msg.AddInt32("data", ::atoi(arg));
  this->SendToProperty(&msg);
}


void
BMAApplication::SetEnd(const char *arg)
{
  BMessage msg(BMA_SET_CHECK_END_TIME);
  msg.AddInt32("data", ::atoi(arg));
  this->SendToProperty(&msg);
}


int
main(int argc, char **argv)
{
  BMAApplication().Run();
}
