// -*- c++ -*- 
//
// BeMailAccount
// Copyright (c) 2001, Okada Jun
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// 
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 
// 3. The name of author may not be used to endorse or promote products
// derived from this software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR
// CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
// EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
// PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
// LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
// NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// 


#ifndef BMA_PROPERTY_H
#define BMA_PROPERTY_H


#include <Message.h>
#include <Looper.h>


class BMessageRunner;


class BMAProperty : public BLooper
{
public:
  BMAProperty(void);
  virtual ~BMAProperty(void);

  int32 CountAccounts(void);
  const char *AccountAt(int32 index);
  int32 IndexOfAccount(const char *account);
  bool HasAccount(const char *account);
  void AddAccount(const char *account);
  void RemoveAccount(const char *account);

  void SetActiveAccount(const char *account);
  const char *ActiveAccount(void);

  void SetCheckDays(int32 data);
  int32 CheckDays(void);
  void SetCheckInterval(int32 data);
  int32 CheckInterval(void);
  void SetCheckBeginTime(int32 data);
  int32 CheckBeginTime(void);
  void SetCheckEndTime(int32 data);
  int32 CheckEndTime(void);

  void SetNotifier(BHandler *notifier);

protected:
  virtual void MessageReceived(BMessage *msg);

private:
  void Read(void);
  void Write(void);
  void InitContainer(void);
  void RestartEMailPrefsIfAlive(void);
  bool IsEMailPrefsAlive(void);
  void QuitEMailPrefs(void);
  void LaunchEMailPrefs(void);

  void CheckNow(void);
  void AutoCheck(void);

  void RestoreAccount(const char *account);
  void StoreAccount(const char *account);

  BMessage mContainer;
  const char *mActiveAccount;
  BMessageRunner *mAutoCheckRunner;
  BHandler *mNotifier;
};


#endif
